@@ -9,7 +9,7 @@ use App::Cmd::Setup -app;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -24,15 +24,16 @@ sub global_opt_spec {
 
 
 sub pinto_remote {
-    my ($self, $command_options) = @_;
-
-    require Pinto::Remote;
-    require Pinto::Remote::Config;
+    my ($self) = @_;
 
     return $self->{pinto_remote} ||= do {
         my %global_options = %{ $self->global_options() };
-        my $config = Pinto::Remote::Config->new(%global_options, %{$command_options});
-        my $pinto_remote = Pinto::Remote->new(config => $config);
+
+        $global_options{host}
+            or $self->usage_error('Must specify a host');
+
+        require Pinto::Remote;
+        my $pinto_remote = Pinto::Remote->new(%global_options);
     };
 }
 
@@ -51,11 +52,11 @@ App::Pinto::Remote - Command line driver for Pinto::Remote
 
 =head1 VERSION
 
-version 0.001
+version 0.017
 
 =head1 METHODS
 
-=head2 pinto_remote( $options )
+=head2 pinto_remote()
 
 Returns a reference to a L<Pinto::Remote> object that has been
 constructed for this application.
