@@ -9,7 +9,7 @@ use base qw(App::Pinto::Remote::Command);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -32,8 +32,8 @@ sub validate_args {
 
 sub execute {
     my ( $self, $opts, $args ) = @_;
-    my $result = $self->pinto_remote( $opts )->add( dist => $args->[0] );
-    print $result->message();
+    my $result = $self->pinto_remote->add( %{$opts}, dist => $args->[0] );
+    print $result->content(), "\n";
     return not $result->status();
 }
 
@@ -52,7 +52,7 @@ App::Pinto::Remote::Command::add - add a local distribution to a remote Pinto re
 
 =head1 VERSION
 
-version 0.001
+version 0.017
 
 =head1 AUTHOR
 
