@@ -4,10 +4,12 @@ package Pinto::Remote;
 
 use Moose;
 
+use Carp;
 use LWP::UserAgent;
+use English qw(-no_match_vars);
 
 use MooseX::Types::Moose qw(Str);
-use Pinto::Types qw(URI AuthorID);
+use Pinto::Types 0.017 qw(URI AuthorID);
 
 use Pinto::Remote::Response;
 
@@ -15,19 +17,50 @@ use namespace::autoclean;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 #-------------------------------------------------------------------------------
 
-with qw(Pinto::Role::Configurable);
+has host => (
+    is       => 'ro',
+    isa      => URI,
+    coerce   => 1,
+    required => 1,
+);
 
-#-------------------------------------------------------------------------------
+has author => (
+    is         => 'ro',
+    isa        => AuthorID,
+    coerce     => 1,
+    lazy_build => 1,
+);
+
+#------------------------------------------------------------------------------
+
+sub _build_author {                                  ## no critic (FinalReturn)
+
+    # Look at typical environment variables
+    for my $var ( qw(USERNAME USER LOGNAME) ) {
+        return uc $ENV{$var} if $ENV{$var};
+    }
+
+    # Try using pwent.  Probably only works on *nix
+    if (my $name = getpwuid($REAL_USER_ID)) {
+        return uc $name;
+    }
+
+    # Otherwise, we are hosed!
+    croak 'Unable to determine your user name';
+
+}
+
+#------------------------------------------------------------------------------
 
 
 sub add {
   my ($self, %args) = @_;
   my $dist   = $args{dist};
-  my $author = $args{author} || $self->config->author();
+  my $author = $args{author} || $self->author();
 
   my %ua_args = (
            Content_Type => 'form-data',
@@ -44,7 +77,7 @@ sub add {
 sub remove {
   my ($self, %args) = @_;
   my $pkg    = $args{package};
-  my $author = $args{author} || $self->config->author();
+  my $author = $args{author} || $self->author();
 
   my %ua_args = (
            Content => [ author => $author, package => $pkg, ],
@@ -59,19 +92,26 @@ sub remove {
 
 sub list {
   my ($self, %args) = @_;
-  return $self->_post('list', ());
+  my $type = $args{type} || 'All';
+
+  my %ua_args = (
+           Content => [ type => $type, ],
+  );
+
+  return $self->_post('list', %ua_args);
 }
 
 #-------------------------------------------------------------------------------
 
 sub _post {
-  my ($self, $action, %args) = @_;
-  my $ua = LWP::UserAgent->new();
-  my $url = $self->config->host() . "/$action";
+  my ($self, $action_name, %args) = @_;
+
+  my $ua       = LWP::UserAgent->new();
+  my $url      = $self->host() . "/action/$action_name";
   my $response = $ua->post($url, %args);
 
   return Pinto::Remote::Response->new( status  => $response->is_success(),
-                                       message => $response->content() );
+                                       content => $response->content() );
 }
 
 #-------------------------------------------------------------------------------
@@ -96,21 +136,21 @@ Pinto::Remote - Interact with a remote Pinto repository
 
 =head1 VERSION
 
-version 0.001
+version 0.017
 
 =head1 METHODS
 
 =head2 add( dist => 'SomeDist-1.2.tar.gz' )
 
-Adds the specified distribution to the remote Pinto repository.  Returns
-a L<Pinto::Remote::Response> that contains the status and diagnostic
-messages from the server.
+Adds the specified distribution to the remote Pinto repository.
+Returns a L<Pinto::Remote::Response> that contains the overall status
+and output from the server.
 
 =head2 remove( package => 'Some::Package' )
 
-Removes the specified package from the remote Pinto repository.  Returns
-a L<Pinto::Remote::Response> that contains the status and diagnostic
-messages from the server.
+Removes the specified package from the remote Pinto repository.
+Returns a L<Pinto::Remote::Response> that contains the overall status
+and output from the server.
 
 =head2 list()
 
